kplr
====

Pythonic access to `Kepler <http://kepler.nasa.gov/>`_ data.

Read `the documentation <http://dan.iel.fm/kplr>`_!
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. image:: http://img.shields.io/pypi/dm/kplr.svg?style=flat
        :target: https://pypi.python.org/pypi/kplr/
.. image:: http://img.shields.io/pypi/v/kplr.svg?style=flat
        :target: https://pypi.python.org/pypi/kplr/
.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
        :target: https://github.com/dfm/kplr/blob/master/LICENSE
